<H1 align="center">

THE BLACKPEARL-FRAMEWORK 

</H1>
<p>OFFICIAL WEBSITE :
<a href="https://blackpearlframework.weebly.com/">Blackpearl-framework</a></p>
<H4 align="center">This is a framework for using most of best hacking tools to work without having an need of commands.</H4> 

<h5>Currently This Framework Is Available For Termux. Under Construction For Kali Linux</h5> 

<img src="https://github.com/FraternityInfoSec/Blackpearl-framework/blob/master/Photo_1600701452267.jpg">

# INSTALLATION 

HOW TO INSTALL :

1.pkg update && upgrade 

2.git clone https://github.com/FraternityInfoSec/Blackpearl-framework.git

3.bash install requirements.sh

4.python install.py


<h3>OR</h3>
<p><h5>pip install pearl</h5>

Now Clear session and open new terminal and just type pearl and enter.

# IMPORTANT COMMANDS

Type below commands in Blackpearl-framework console : 

help   : For any help of using framework 

exit   : To exit from console


# FEATURES 

YOU CAN USE THIS FOR :

1.AUTOMATION OF MAIN PAYLOADS OF METASPLOIT FRAMEWORK 

2 DIFFERENT BRUTEFORCE AUTOMATION USING HYDRA 

3.SQLMAP AUTOMATION FOR PENETRATION OF SQL VULNERABLE WEBSITES 

4.MAKE CUSTOM WORDLIST OR AUTO WORLDLIST

5 NMAP AUTOMATION FOR FINDING OPEN PORTS AND OTHER 30 TYPES OF SCANNING AND PENETRATIONS

6 POWERFUL AUTOMATED DISTRIBUTIED DENIAL OF SERVICE 

And we had given 3 password list contains more than 10k passwords. 

# CONTACT 

Use can contact us for issues or problems on our email Cipherweb777@gmail.com 

# DISCLAIMER 

WE ARE NOT RESPONSIBLE FOR ANY ILLEGAL ACTIVITIES BY THIS PROJECT. THIS FOR ONLY EDUCATIONAL PURPOSES AND CHECKING YOUR OWN WEBSITES AND OTHERS SECURITY. 

<H3 align="center"> FROM FRATERNITY INFOTECH GROUP</H3>


